@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0204';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -68,7 +68,7 @@ sub generate {
     my @notes = map { Music::Note->new($_, 'ISO')->format('midinum') }
         $cn->chord_with_octave($chord, $self->octave);
 
-    my @pitches = get_scale_MIDI($chord_note, $self->octave, $scale);
+    my @pitches = $scale ? get_scale_MIDI($chord_note, $self->octave, $scale) : ();
 
     # Add unique chord notes to the pitches
     for my $n (@notes) {
@@ -133,7 +133,7 @@ sub generate {
     $voice->context($fixed[int @fixed / 2]);
 
     # Choose Or Die!!
-    my @chosen = map { $voice->rand } 1 .. $num;;
+    my @chosen = map { $voice->rand } 1 .. $num;
 
     # Show them what they've won, Bob!
     if ($self->verbose) {
@@ -158,7 +158,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 SYNOPSIS
 
@@ -220,6 +220,12 @@ Alternatives:
 
   sub { $_[0] =~ /^[A-G][#b]?m/ ? 'pminor' : 'pentatonic' }
 
+  sub { '' }
+
+The first walks the chromatic scale no matter what the chord.  The
+second walks only the major or minor pentatonic scale.  The last walks
+only the notes of the chord (no scale).
+
 =head2 verbose
 
   $verbose = $bassline->verbose;
